[SCM] libav/experimental: Rename avfilter_destroy() as avfilter_free().

siretart at users.alioth.debian.org siretart at users.alioth.debian.org
Sun Jun 30 17:18:49 UTC 2013


The following commit has been merged in the experimental branch:
commit 24de0edbd589b7cb0da51260073a1a28bb6a2619
Author: Stefano Sabatini <stefano.sabatini-lala at poste.it>
Date:   Mon Nov 8 12:32:39 2010 +0000

    Rename avfilter_destroy() as avfilter_free().
    
    The new name is shorter and more consistent with the FFmpeg API, and
    sounds less evil.
    
    Originally committed as revision 25707 to svn://svn.ffmpeg.org/ffmpeg/trunk

diff --git a/doc/APIchanges b/doc/APIchanges
index 63f33b4..d676b6a 100644
--- a/doc/APIchanges
+++ b/doc/APIchanges
@@ -13,6 +13,10 @@ libavutil:   2009-03-08
 
 API changes, most recent first:
 
+2010-11-08 - r25707 - lavfi 1.59.0 - avfilter_free()
+  Rename avfilter_destroy() to avfilter_free().
+  This change breaks libavfilter API/ABI.
+
 2010-11-07 - r25705 - lavfi 1.58.0 - avfiltergraph.h
   Remove graphparser.h header, move AVFilterInOut and
   avfilter_graph_parse() declarations to libavfilter/avfiltergraph.h.
diff --git a/libavfilter/avfilter.c b/libavfilter/avfilter.c
index db85718..fa15b35 100644
--- a/libavfilter/avfilter.c
+++ b/libavfilter/avfilter.c
@@ -527,7 +527,7 @@ int avfilter_open(AVFilterContext **filter_ctx, AVFilter *filter, const char *in
     return 0;
 }
 
-void avfilter_destroy(AVFilterContext *filter)
+void avfilter_free(AVFilterContext *filter)
 {
     int i;
     AVFilterLink *link;
diff --git a/libavfilter/avfiltergraph.c b/libavfilter/avfiltergraph.c
index 6ce312b..16c0355 100644
--- a/libavfilter/avfiltergraph.c
+++ b/libavfilter/avfiltergraph.c
@@ -34,7 +34,7 @@ AVFilterGraph *avfilter_graph_alloc(void)
 void avfilter_graph_free(AVFilterGraph *graph)
 {
     for(; graph->filter_count > 0; graph->filter_count --)
-        avfilter_destroy(graph->filters[graph->filter_count - 1]);
+        avfilter_free(graph->filters[graph->filter_count - 1]);
     av_freep(&graph->scale_sws_opts);
     av_freep(&graph->filters);
 }
@@ -143,7 +143,7 @@ static int query_formats(AVFilterGraph *graph, AVClass *log_ctx)
                     snprintf(scale_args, sizeof(scale_args), "0:0:%s", graph->scale_sws_opts);
                     if(!scale || scale->filter->init(scale, scale_args, NULL) ||
                                  avfilter_insert_filter(link, scale, 0, 0)) {
-                        avfilter_destroy(scale);
+                        avfilter_free(scale);
                         return -1;
                     }
 
diff --git a/libavfilter/graphparser.c b/libavfilter/graphparser.c
index 1bce3bc..4266e81 100644
--- a/libavfilter/graphparser.c
+++ b/libavfilter/graphparser.c
@@ -118,7 +118,7 @@ static int create_filter(AVFilterContext **filt_ctx, AVFilterGraph *ctx, int ind
     }
 
     if ((ret = avfilter_graph_add_filter(ctx, *filt_ctx)) < 0) {
-        avfilter_destroy(*filt_ctx);
+        avfilter_free(*filt_ctx);
         return ret;
     }
 
diff --git a/tools/lavfi-showfiltfmts.c b/tools/lavfi-showfiltfmts.c
index 34a6208..19bb6f6 100644
--- a/tools/lavfi-showfiltfmts.c
+++ b/tools/lavfi-showfiltfmts.c
@@ -93,7 +93,7 @@ int main(int argc, char **argv)
                    av_pix_fmt_descriptors[fmts->formats[j]].name);
     }
 
-    avfilter_destroy(filter_ctx);
+    avfilter_free(filter_ctx);
     fflush(stdout);
     return 0;
 }

diff --git a/libavfilter/avfilter.h b/libavfilter/avfilter.h
index 544c2e9..18feadc 100644
--- a/libavfilter/avfilter.h
+++ b/libavfilter/avfilter.h
@@ -25,7 +25,7 @@
 #include "libavutil/avutil.h"
 
 #define LIBAVFILTER_VERSION_MAJOR  1
-#define LIBAVFILTER_VERSION_MINOR 58
+#define LIBAVFILTER_VERSION_MINOR 59
 #define LIBAVFILTER_VERSION_MICRO  0
 
 #define LIBAVFILTER_VERSION_INT AV_VERSION_INT(LIBAVFILTER_VERSION_MAJOR, \
@@ -786,11 +786,11 @@ int avfilter_open(AVFilterContext **filter_ctx, AVFilter *filter, const char *in
 int avfilter_init_filter(AVFilterContext *filter, const char *args, void *opaque);
 
 /**
- * Destroy a filter.
+ * Free a filter context.
  *
  * @param filter the filter to destroy
  */
-void avfilter_destroy(AVFilterContext *filter);
+void avfilter_free(AVFilterContext *filter);
 
 /**
  * Insert a filter in the middle of an existing link.
@@ -786,11 +786,11 @@ int avfilter_open(AVFilterContext **filter_ctx, AVFilter *filter, const char *in
  *
- * @param filter the filter to destroy
+ * @param filter the filter to free
  */
-- 
Libav/FFmpeg packaging



More information about the pkg-multimedia-commits mailing list